#ifndef DIE_H
#define DIE_H

#include <QTime>
#include <QThread>
#include <QObject>
#include <QDebug>

class Die : public QObject
{
    Q_OBJECT
private:
    static int instances;
    int eyes;
    int randomToken;
public:
    explicit Die(int eyes, QObject *parent = 0);
    virtual ~Die();
    void setEyes(int eyes);
    int getEyes() const;
    int getOutcome() const;
signals:
    void signalEyesChanged(int eyes);
};

#endif // DIE_H
